@@ -1,10 +1,7 @@
 import keyring
-import random
-import json
-import hmac
-import os
 from easyrsa import EasyRSA
 from omnitools import *
+from aescipher import *
 
 
 __ALL__ = ["Broker"]
@@ -76,6 +73,7 @@ class Broker(object):
     def destroy(self) -> bool:
         self.__delete()
         self.__username = None
+        self.__app_name = None
         return True
 
 
